"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IndexWorldsActionProcessorTaskMapper = exports.IndexWorldsActionMongoMapper = void 0;
const aw_core_1 = require("@alien-worlds/aw-core");
const hdlegovchg_mapper_1 = require("./hdlegovchg.mapper");
const regaccount_mapper_1 = require("./regaccount.mapper");
const regdac_mapper_1 = require("./regdac.mapper");
const regref_mapper_1 = require("./regref.mapper");
const setowner_mapper_1 = require("./setowner.mapper");
const setsociallnk_mapper_1 = require("./setsociallnk.mapper");
const setsocials_mapper_1 = require("./setsocials.mapper");
const setstatus_mapper_1 = require("./setstatus.mapper");
const settitle_mapper_1 = require("./settitle.mapper");
const unregaccount_mapper_1 = require("./unregaccount.mapper");
const unregdac_mapper_1 = require("./unregdac.mapper");
const unregref_mapper_1 = require("./unregref.mapper");
const aw_storage_mongodb_1 = require("@alien-worlds/aw-storage-mongodb");
const enums_1 = require("../../domain/enums");
class IndexWorldsActionMongoMapper extends aw_storage_mongodb_1.MongoMapper {
    fromEntity(entity) {
        let entityData;
        switch (entity.name) {
            case enums_1.IndexWorldsActionName.Hdlegovchg:
                entityData = new hdlegovchg_mapper_1.HdlegovchgMongoMapper().fromEntity(entity.data);
                break;
            case enums_1.IndexWorldsActionName.Regaccount:
                entityData = new regaccount_mapper_1.RegaccountMongoMapper().fromEntity(entity.data);
                break;
            case enums_1.IndexWorldsActionName.Regdac:
                entityData = new regdac_mapper_1.RegdacMongoMapper().fromEntity(entity.data);
                break;
            case enums_1.IndexWorldsActionName.Regref:
                entityData = new regref_mapper_1.RegrefMongoMapper().fromEntity(entity.data);
                break;
            case enums_1.IndexWorldsActionName.Setowner:
                entityData = new setowner_mapper_1.SetownerMongoMapper().fromEntity(entity.data);
                break;
            case enums_1.IndexWorldsActionName.Setsociallnk:
                entityData = new setsociallnk_mapper_1.SetsociallnkMongoMapper().fromEntity(entity.data);
                break;
            case enums_1.IndexWorldsActionName.Setsocials:
                entityData = new setsocials_mapper_1.SetsocialsMongoMapper().fromEntity(entity.data);
                break;
            case enums_1.IndexWorldsActionName.Setstatus:
                entityData = new setstatus_mapper_1.SetstatusMongoMapper().fromEntity(entity.data);
                break;
            case enums_1.IndexWorldsActionName.Settitle:
                entityData = new settitle_mapper_1.SettitleMongoMapper().fromEntity(entity.data);
                break;
            case enums_1.IndexWorldsActionName.Unregaccount:
                entityData = new unregaccount_mapper_1.UnregaccountMongoMapper().fromEntity(entity.data);
                break;
            case enums_1.IndexWorldsActionName.Unregdac:
                entityData = new unregdac_mapper_1.UnregdacMongoMapper().fromEntity(entity.data);
                break;
            case enums_1.IndexWorldsActionName.Unregref:
                entityData = new unregref_mapper_1.UnregrefMongoMapper().fromEntity(entity.data);
                break;
        }
        const model = {
            block_timestamp: entity.blockTimestamp,
            block_number: new aw_storage_mongodb_1.MongoDB.Long(entity.blockNumber),
            global_sequence: new aw_storage_mongodb_1.MongoDB.Long(entity.globalSequence),
            receiver_sequence: new aw_storage_mongodb_1.MongoDB.Long(entity.receiverSequence),
            trx_id: entity.transactionId,
            action: {
                name: entity.name,
                account: entity.account,
                data: entityData,
            },
        };
        if (entity.id && aw_storage_mongodb_1.MongoDB.ObjectId.isValid(entity.id)) {
            model._id = new aw_storage_mongodb_1.MongoDB.ObjectId(entity.id);
        }
        return model;
    }
    toEntity(mongoModel) {
        let data;
        switch (mongoModel.action.name) {
            case enums_1.IndexWorldsActionName.Hdlegovchg:
                data = new hdlegovchg_mapper_1.HdlegovchgMongoMapper().toEntity(mongoModel.action.data);
                break;
            case enums_1.IndexWorldsActionName.Regaccount:
                data = new regaccount_mapper_1.RegaccountMongoMapper().toEntity(mongoModel.action.data);
                break;
            case enums_1.IndexWorldsActionName.Regdac:
                data = new regdac_mapper_1.RegdacMongoMapper().toEntity(mongoModel.action.data);
                break;
            case enums_1.IndexWorldsActionName.Regref:
                data = new regref_mapper_1.RegrefMongoMapper().toEntity(mongoModel.action.data);
                break;
            case enums_1.IndexWorldsActionName.Setowner:
                data = new setowner_mapper_1.SetownerMongoMapper().toEntity(mongoModel.action.data);
                break;
            case enums_1.IndexWorldsActionName.Setsociallnk:
                data = new setsociallnk_mapper_1.SetsociallnkMongoMapper().toEntity(mongoModel.action.data);
                break;
            case enums_1.IndexWorldsActionName.Setsocials:
                data = new setsocials_mapper_1.SetsocialsMongoMapper().toEntity(mongoModel.action.data);
                break;
            case enums_1.IndexWorldsActionName.Setstatus:
                data = new setstatus_mapper_1.SetstatusMongoMapper().toEntity(mongoModel.action.data);
                break;
            case enums_1.IndexWorldsActionName.Settitle:
                data = new settitle_mapper_1.SettitleMongoMapper().toEntity(mongoModel.action.data);
                break;
            case enums_1.IndexWorldsActionName.Unregaccount:
                data = new unregaccount_mapper_1.UnregaccountMongoMapper().toEntity(mongoModel.action.data);
                break;
            case enums_1.IndexWorldsActionName.Unregdac:
                data = new unregdac_mapper_1.UnregdacMongoMapper().toEntity(mongoModel.action.data);
                break;
            case enums_1.IndexWorldsActionName.Unregref:
                data = new unregref_mapper_1.UnregrefMongoMapper().toEntity(mongoModel.action.data);
                break;
        }
        const { _id, block_timestamp, block_number, global_sequence, receiver_sequence, trx_id, action, } = mongoModel;
        return new aw_core_1.ContractAction(_id.toString(), block_timestamp, (0, aw_core_1.parseToBigInt)(block_number), action.account, action.name, (0, aw_core_1.parseToBigInt)(global_sequence), (0, aw_core_1.parseToBigInt)(receiver_sequence), trx_id, data);
    }
}
exports.IndexWorldsActionMongoMapper = IndexWorldsActionMongoMapper;
class IndexWorldsActionProcessorTaskMapper extends aw_core_1.MapperImpl {
    fromEntity(entity) {
        throw new Error('method not implemented');
    }
    toEntity(rawModel) {
        let data;
        switch (rawModel.name) {
            case enums_1.IndexWorldsActionName.Hdlegovchg:
                data = new hdlegovchg_mapper_1.HdlegovchgRawMapper().toEntity(rawModel.data);
                break;
            case enums_1.IndexWorldsActionName.Regaccount:
                data = new regaccount_mapper_1.RegaccountRawMapper().toEntity(rawModel.data);
                break;
            case enums_1.IndexWorldsActionName.Regdac:
                data = new regdac_mapper_1.RegdacRawMapper().toEntity(rawModel.data);
                break;
            case enums_1.IndexWorldsActionName.Regref:
                data = new regref_mapper_1.RegrefRawMapper().toEntity(rawModel.data);
                break;
            case enums_1.IndexWorldsActionName.Setowner:
                data = new setowner_mapper_1.SetownerRawMapper().toEntity(rawModel.data);
                break;
            case enums_1.IndexWorldsActionName.Setsociallnk:
                data = new setsociallnk_mapper_1.SetsociallnkRawMapper().toEntity(rawModel.data);
                break;
            case enums_1.IndexWorldsActionName.Setsocials:
                data = new setsocials_mapper_1.SetsocialsRawMapper().toEntity(rawModel.data);
                break;
            case enums_1.IndexWorldsActionName.Setstatus:
                data = new setstatus_mapper_1.SetstatusRawMapper().toEntity(rawModel.data);
                break;
            case enums_1.IndexWorldsActionName.Settitle:
                data = new settitle_mapper_1.SettitleRawMapper().toEntity(rawModel.data);
                break;
            case enums_1.IndexWorldsActionName.Unregaccount:
                data = new unregaccount_mapper_1.UnregaccountRawMapper().toEntity(rawModel.data);
                break;
            case enums_1.IndexWorldsActionName.Unregdac:
                data = new unregdac_mapper_1.UnregdacRawMapper().toEntity(rawModel.data);
                break;
            case enums_1.IndexWorldsActionName.Unregref:
                data = new unregref_mapper_1.UnregrefRawMapper().toEntity(rawModel.data);
                break;
        }
        const { account, name, block_timestamp, block_number, global_sequence, recv_sequence, transaction_id, } = rawModel;
        return new aw_core_1.ContractAction('', block_timestamp, (0, aw_core_1.parseToBigInt)(block_number), account, name, (0, aw_core_1.parseToBigInt)(global_sequence), (0, aw_core_1.parseToBigInt)(recv_sequence), transaction_id, data);
    }
}
exports.IndexWorldsActionProcessorTaskMapper = IndexWorldsActionProcessorTaskMapper;
