"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DacsRawMapper = exports.DacsMongoMapper = void 0;
const aw_core_1 = require("@alien-worlds/aw-core");
const aw_storage_mongodb_1 = require("@alien-worlds/aw-storage-mongodb");
const aw_antelope_1 = require("@alien-worlds/aw-antelope");
const entities_1 = require("../../domain/entities");
class DacsMongoMapper extends aw_storage_mongodb_1.MongoMapper {
    constructor() {
        super();
        this.mappingFromEntity.set('owner', {
            key: 'owner',
            mapper: (value) => value,
        });
        this.mappingFromEntity.set('dacId', {
            key: 'dac_id',
            mapper: (value) => value,
        });
        this.mappingFromEntity.set('title', {
            key: 'title',
            mapper: (value) => value,
        });
        this.mappingFromEntity.set('symbol', {
            key: 'symbol',
            mapper: (value) => new aw_antelope_1.ExtendedSymbolMongoMapper().fromEntity(value),
        });
        this.mappingFromEntity.set('refs', {
            key: 'refs',
            mapper: (values) => values.map(value => new aw_antelope_1.PairMongoMapper().fromEntity(value)),
        });
        this.mappingFromEntity.set('accounts', {
            key: 'accounts',
            mapper: (values) => values.map(value => new aw_antelope_1.PairMongoMapper().fromEntity(value)),
        });
        this.mappingFromEntity.set('dacState', {
            key: 'dac_state',
            mapper: (value) => value,
        });
    }
    toEntity(mongoModel) {
        const { owner, dac_id, title, symbol, refs, accounts, dac_state, _id, ...rest } = mongoModel;
        return entities_1.Dacs.create(owner || '', dac_id || '', title || '', symbol ? new aw_antelope_1.ExtendedSymbolMongoMapper().toEntity(symbol) : aw_antelope_1.ExtendedSymbol.getDefault(), refs?.map(value => new aw_antelope_1.PairMongoMapper().toEntity(value)) || [], accounts?.map(value => new aw_antelope_1.PairMongoMapper().toEntity(value)) || [], dac_state || 0, _id instanceof aw_storage_mongodb_1.MongoDB.ObjectId ? _id.toString() : undefined, rest);
    }
}
exports.DacsMongoMapper = DacsMongoMapper;
class DacsRawMapper extends aw_core_1.MapperImpl {
    fromEntity(entity) {
        throw new Error('Method not implemented');
    }
    toEntity(rawModel) {
        const { owner, dac_id, title, symbol, refs, accounts, dac_state, ...rest } = rawModel;
        return entities_1.Dacs.create(owner || '', dac_id || '', title || '', symbol ? new aw_antelope_1.ExtendedSymbolRawMapper().toEntity(symbol) : aw_antelope_1.ExtendedSymbol.getDefault(), refs?.map(value => new aw_antelope_1.PairRawMapper().toEntity(value)) || [], accounts?.map(value => new aw_antelope_1.PairRawMapper().toEntity(value)) || [], dac_state || 0, undefined, rest);
    }
}
exports.DacsRawMapper = DacsRawMapper;
